pyBioDataFuse |release| Documentation
=====================================

.. automodule:: pyBioDataFuse

## 💪 Getting Started

- pyBioDataFuse is a python package for integrating data from multiple existing biomedical resources and
- assist in generating a knowledge graph on the data.


Table of Contents
-----------------
.. toctree::
   :maxdepth: 2
   :caption: Getting Started
   :name: start

   installation
   datasources
   graph_plotters

Indices and Tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Disclaimer
------------
This package was created with the `cookiecutter <https://github.com/cookiecutter/cookiecutter>`_
package using `cookiecutter-snekpack <https://github.com/cthoyt/cookiecutter-snekpack>`_ template.
